package com.nova.nova_utils;

import android.app.Activity;

import com.ark.commons.ArkTool;
import com.ark.commons.type.agreement.AgreementInterface;
import com.ark.commons.type.agreement.AgreementManager;
import com.ark.commons.type.start.StartManager;
import com.ark.dict.ConfigMapLoader;
import com.leon.channel.helper.ChannelReaderUtil;
import com.tencent.mmkv.MMKV;

import java.util.Map;

import androidx.fragment.app.FragmentActivity;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * NovaUtilsPlugin
 */
public class NovaUtilsPlugin implements MethodCallHandler, ActivityAware {

    private static Activity activity;



    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "nova_utils");
        activity =  registrar.activity();
        channel.setMethodCallHandler(new NovaUtilsPlugin());
    }

    @Override
    public void onMethodCall(MethodCall call, final Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("launchMarket")) {
            CommonUtils.toMarket(activity);
        } else if (call.method.equals("checkUpdate")){
            ArkTool.getUpdateManager().checkUpdate(activity);
        }else if (call.method.equals("rateApp")){
            ArkTool.getRateManager().showRateDialog(activity);
        }else if (call.method.equals("popPrivacy")){
            ArkTool.getAgreementManager().showAgreementDialog(activity);
        }else if (call.method.equals("launchUserAgreement")){
            ArkTool.getAgreementManager().showUserAgreement(activity);
        }else if (call.method.equals("launchPrivacyAgreement")){
            ArkTool.getAgreementManager().showPrivacyAgreement(activity);
        }else if (call.method.equals("setDefaultAgreement")){
            CommonUtils.initMMKV(activity);
            String channel = ChannelReaderUtil.getChannel(activity);
            ArkTool.setOnlineUrlConfig(activity,channel);
            result.success(true);
        }else if (call.method.equals("setUserAndPrivacyAgreement")){
            CommonUtils.initMMKV(activity);
            String userUrl = call.argument("userUrl");
            String privacyUrl = call.argument("privacyUrl");
            AgreementManager.Configuration configuration = new AgreementManager.Configuration();
            configuration.setUser_url(userUrl);
            configuration.setPrivacy_url(privacyUrl);
            AgreementManager.setConfig(activity,configuration);
            result.success(true);
        }else if (call.method.equals("startAndroidApp")){
            CommonUtils.initMMKV(activity);
            ArkTool.getStartManager().startApp(activity, new AgreementInterface.AgreementCallback() {
                @Override
                public void onConfirm() {
                    ConfigMapLoader.getInstance().getData();
                    result.success(true);
                }
            });
        }else if (call.method.equals("getAdditionalConfigParams")){
            CommonUtils.initMMKV(activity);
            String key = call.arguments();
            Map<String, String> other_data = ConfigMapLoader.getInstance().getConfigBean().getOther_data();
            if (other_data!=null){
                if (other_data.containsKey(key)){
                    result.success(other_data.get(key));
                }else {
                    result.success(null);
                }
            }else {
                result.success(null);
            }

        }else {
            result.notImplemented();
        }
    }


    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        activity = (FragmentActivity) binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {
         activity = (FragmentActivity) binding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {

    }
}
