#import "NovaUtilsPlugin.h"
#import <UICKeyChainStore/UICKeyChainStore.h>
#import <NOVRemoteConfig/NOVARemoteConfig.h>
#import <NOVAppUpgrade/NOVAAppUpgrade.h>
#import <NOVPrivacy/NOVAPrivacy.h>
#import <NOVAppReview/NOVAAppReview.h>

@interface NovaUtilsPlugin ()
@property (nonatomic, strong) NSMutableDictionary *defaultDic;
@end

@implementation NovaUtilsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"nova_utils"
            binaryMessenger:[registrar messenger]];
  static NovaUtilsPlugin *instance;
  instance = [[NovaUtilsPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (instancetype)init {
    self = [super init];
    if (self) {

        [[NOVARemoteConfig shared] setup];
        NSData *defaultDicData = [[UICKeyChainStore keyChainStoreWithService:@"com.NovaUtilsPlugin.dic"] dataForKey:@"default"];
        if (defaultDicData == nil) {
            self.defaultDic = [NSMutableDictionary dictionary];
        } else {
            self.defaultDic = [NSMutableDictionary dictionaryWithDictionary: [NSJSONSerialization JSONObjectWithData:defaultDicData options:0 error:nil]];
        }
        NSLog(@"[NovaUtilsPlugin] read dic from keychain: %@", self.defaultDic);
    }
    
    return self;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getKeyChainValue" isEqualToString:call.method]) {
      NSArray *keys = call.arguments;
      NSMutableDictionary<NSString *, NSString *> *dic = [[NSMutableDictionary alloc] init];
      [keys enumerateObjectsUsingBlock:^(NSString * _Nonnull obj, NSUInteger idx, BOOL * _Nonnull stop) {
          id value = self.defaultDic[obj];
          if (value != nil) {
              dic[obj] = value;
          }
      }];
      
      result(dic);
  } else if ([@"setKeyChainValue" isEqualToString:call.method]) {
      NSDictionary *dic = call.arguments;
      
      [dic enumerateKeysAndObjectsUsingBlock:^(id  _Nonnull key, id  _Nonnull obj, BOOL * _Nonnull stop) {
          [self.defaultDic setObject:obj forKey:key];
      }];
      
      NSData *defaultDicData = [NSJSONSerialization dataWithJSONObject:self.defaultDic options:0 error:nil];
      [[UICKeyChainStore keyChainStoreWithService:@"com.NovaUtilsPlugin.dic"] setData:defaultDicData forKey:@"default"];
      result([NSNumber numberWithBool:true]);
  }
  else if ([@"launchMarket" isEqualToString:call.method]) {
    NSString *urlString = call.arguments;

    [[UIApplication sharedApplication] openURL:[NSURL URLWithString:urlString]];
    result([NSNumber numberWithBool:true]);

  } else if ([@"checkUpdate" isEqualToString: call.method]) {
    [[NOVAAppUpgrade shared] checkNewVersion];
    result([NSNumber numberWithBool:true]);
  }
  else if ([@"rateApp" isEqualToString: call.method]) {
    [[NOVAAppReview shared] show];
    result([NSNumber numberWithBool:true]);

  }
  else if ([@"popPrivacy" isEqualToString: call.method]) {
    [NOVAPrivacyViewController show];
    result([NSNumber numberWithBool:true]);
  }
  else if ([@"launchUserAgreement" isEqualToString: call.method]) {
    [NOVAPrivacyViewController presentUserAgreement];
    result([NSNumber numberWithBool:true]);
  }
  else if ([@"launchPrivacyAgreement" isEqualToString: call.method]) {
    [NOVAPrivacyViewController presentPrivacy];
    result([NSNumber numberWithBool:true]);
  }
  else if ([@"getAdditionalConfigParams" isEqualToString: call.method]) {
    NSString *key = call.arguments;
    if (key) {
      result([[[NOVARemoteConfig shared].configs objectForKey:@"other_data"] objectForKey:key]);
    } else {
      result(nil);
    }
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}

@end
