import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class NovaUtils {
  static const MethodChannel _channel = const MethodChannel('nova_utils');

  //IOS 获取钥匙链的值
  static Future<Map<String, String>> getKeyChainValue(
      List<String> paramsName) async {
    if (Platform.isIOS) {
      final Map<String, String> value = new Map<String, String>.from(
          await _channel.invokeMethod('getKeyChainValue', paramsName));
      return value;
    } else {
      return null;
    }
  }

  //IOS 设置钥匙链的值
  static Future<bool> setKeyChanValue(Map<String, String> params) async {
    if (Platform.isIOS) {
      final bool value =
          await _channel.invokeMethod('setKeyChainValue', params);
      return value;
    } else {
      return false;
    }
  }

  static Future<void> launchMarket({String iosUrl}) async {
    if (Platform.isIOS) {
      await _channel.invokeMethod('launchMarket', iosUrl);
    } else {
      await _channel.invokeMethod('launchMarket');
    }
  }

  //新KV 检测升级
  static Future<void> checkUpdate() async {
    _channel.invokeMethod('checkUpdate');
  }

  //好评弹窗
  static Future<void> rateApp() async {
    _channel.invokeMethod('rateApp');
  }

  //隐私政策弹窗
  static Future<void> showPrivacy() async {
    _channel.invokeMethod('popPrivacy');
  }

  // 跳转用户协议
  static Future<void> launchUserAgreement() async {
    _channel.invokeMethod('launchUserAgreement');
  }

  // 跳转隐私协议
  static Future<void> launchPrivacyAgreement() async {
    _channel.invokeMethod('launchPrivacyAgreement');
  }


  static Future<bool> setUserAndPrivacyAgreement(
      String userAgreement, String privacyAgreement) async {
    var params = {"userUrl": userAgreement, "privacyUrl": privacyAgreement};
    return await _channel.invokeMethod("setUserAndPrivacyAgreement", params);
  }
  static Future<bool> setDefaultAgreement() async{
    return await _channel.invokeMethod("setDefaultAgreement");
  }

  //Android 开机展示隐私协议接口
  static Future<bool> setStartAndroidApp() async {
    return await _channel.invokeMethod("startAndroidApp");
  }

  //获取后台otherData配置
  static Future<String> getConfigParams(String key) async {
    var result = await _channel.invokeMethod('getAdditionalConfigParams', key);
    return result == null ? "" : result;
  }
}
